@@ -378,10 +378,11 @@ from copy import deepcopy
 from typing import Any, Callable, Dict, List, Optional, Tuple, Type, Union
 
 from ae.base import (                                                                                   # type: ignore
-    CFG_EXT, INI_EXT, NAME_PARTS_SEP, UNSET, instantiate_config_parser, norm_name, now_str, os_platform, snake_to_camel)
+    CFG_EXT, INI_EXT, NAME_PARTS_SEP, UNSET,
+    instantiate_config_parser, norm_name, norm_path, now_str, os_platform, snake_to_camel)
 from ae.files import RegisteredFile                                                                     # type: ignore
 from ae.paths import (                                                                                  # type: ignore
-    add_common_storage_paths, copy_file, copy_tree, norm_path, path_folders, path_name, placeholder_path,
+    add_common_storage_paths, copy_file, copy_tree, normalize, path_folders, path_name, placeholder_path,
     Collector, FilesRegister, placeholder_key)
 from ae.updater import MOVES_SRC_FOLDER_NAME, check_all                                                 # type: ignore
 from ae.inspector import stack_var                                                                      # type: ignore
@@ -391,7 +392,7 @@ from ae.core import DEBUG_LEVELS, registered_app_names
 from ae.console import ConsoleApp                                                                       # type: ignore
 
 
-__version__ = '0.2.83'
+__version__ = '0.3.83'
 
 
 AppStateType = Dict[str, Any]                   #: app state config variable type
@@ -436,7 +437,8 @@ PORTIONS_SOUNDS = FilesRegister()               #: register of sound files found
 USER_NAME_MAX_LEN = 12          #: maximal length of a user name/id (restricting :attr:`~ae.console.ConsoleApp.user_id`)
 
 
-check_all()     # let ae_updater module check/install any outstanding updates or new app versions
+if stack_var('__name__') == '__main__':         # only if imported directly from main app module
+    check_all()                                 # .. check/install any outstanding updates or new app versions
 
 
 def ensure_tap_kwargs_refs(init_kwargs: EventKwargsType, tap_widget: Any):
@@ -448,22 +450,22 @@ def ensure_tap_kwargs_refs(init_kwargs: EventKwargsType, tap_widget: Any):
     this alternative version is only 10 % faster but much less clean than the current implementation::
 
         if 'tap_kwargs' not in init_kwargs:
-            init_kwargs['tap_kwargs'] = dict()
+            init_kwargs['tap_kwargs'] = {}
         tap_kwargs = init_kwargs['tap_kwargs']
 
         if 'tap_widget' not in tap_kwargs:
             tap_kwargs['tap_widget'] = tap_widget
 
         if 'popup_kwargs' not in tap_kwargs:
-            tap_kwargs['popup_kwargs'] = dict()
+            tap_kwargs['popup_kwargs'] = {}
         popup_kwargs = tap_kwargs['popup_kwargs']
         if 'parent' not in popup_kwargs:
             popup_kwargs['parent'] = tap_kwargs['tap_widget']
 
     """
-    init_kwargs['tap_kwargs'] = tap_kwargs = init_kwargs.get('tap_kwargs', dict())
+    init_kwargs['tap_kwargs'] = tap_kwargs = init_kwargs.get('tap_kwargs', {})
     tap_kwargs['tap_widget'] = tap_widget = tap_kwargs.get('tap_widget', tap_widget)
-    tap_kwargs['popup_kwargs'] = popup_kwargs = tap_kwargs.get('popup_kwargs', dict())
+    tap_kwargs['popup_kwargs'] = popup_kwargs = tap_kwargs.get('popup_kwargs', {})
     popup_kwargs['parent'] = popup_kwargs.get('parent', tap_widget)
 
 
@@ -609,7 +611,7 @@ def register_package_images():
     """
     global PORTIONS_IMAGES
 
-    package_path = os.path.abspath(os.path.dirname(stack_var('__file__', '')))
+    package_path = os.path.dirname(norm_path(stack_var('__file__', '')))
     search_path = os.path.join(package_path, 'img/**')
     PORTIONS_IMAGES.add_paths(search_path)
 
@@ -626,7 +628,7 @@ def register_package_sounds():
     """
     global PORTIONS_SOUNDS
 
-    package_path = os.path.abspath(os.path.dirname(stack_var('__file__', '')))
+    package_path = os.path.dirname(norm_path(stack_var('__file__', '')))
     search_path = os.path.join(package_path, 'snd/**')
     PORTIONS_SOUNDS.add_paths(search_path)
 
@@ -649,7 +651,7 @@ def update_tap_kwargs(widget: Any, popup_kwargs: Optional[EventKwargsType] = Non
     :param tap_kwargs:          additional tap_kwargs items to update.
     :return:
     """
-    handle = dict(tap_kwargs=widget.tap_kwargs) if hasattr(widget, 'tap_kwargs') else dict()
+    handle = dict(tap_kwargs=widget.tap_kwargs) if hasattr(widget, 'tap_kwargs') else {}
     ensure_tap_kwargs_refs(handle, widget)
     new_kwargs = handle['tap_kwargs']
     if popup_kwargs:
@@ -701,7 +703,7 @@ class MainAppBase(ConsoleApp, ABC):
         self._start_event_loop: Optional[Callable]          #: callable to start event loop of GUI framework
         self._stop_event_loop: Optional[Callable]           #: callable to start event loop of GUI framework
 
-        self.flow_path = list()     # init for literal type recognition - will be overwritten by setup_app_states()
+        self.flow_path = []         # init for literal type recognition - will be overwritten by setup_app_states()
 
         add_common_storage_paths()  # determine platform specific path placeholders, like e.g. {pictures}, {downloads}..
 
@@ -755,7 +757,7 @@ class MainAppBase(ConsoleApp, ABC):
 
         resources are copied from {ado} or {cwd} (only the first found resources root path).
         """
-        backup_root = norm_path("{ado}") + now_str(sep="_")
+        backup_root = normalize("{ado}") + now_str(sep="_")
         os.makedirs(backup_root)
 
         coll = Collector()
@@ -1012,7 +1014,7 @@ class MainAppBase(ConsoleApp, ABC):
         glo_vars.update((k, v) for k, v in globals().items() if k not in HIDDEN_GLOBALS)
         glo_vars['app'] = self.framework_app
         glo_vars['main_app'] = self
-        glo_vars['_add_base_globals'] = True        # instruct ae.inspector.try_eval to add ae.core globals
+        glo_vars['_add_base_globals'] = ""          # instruct ae.inspector.try_eval to add generic/base globals
 
         self.vpo(f"MainAppBase.global_variables patching {patches} over {glo_vars}")
 
@@ -1057,7 +1059,7 @@ class MainAppBase(ConsoleApp, ABC):
 
     def load_app_states(self):
         """ load application state from the config files to prepare app.run_app """
-        app_states = dict()
+        app_states = {}
         for key in self.app_state_keys():
             app_states[key] = self.get_var(key, section=APP_STATE_SECTION_NAME)
             if self.debug:
@@ -1169,7 +1171,7 @@ class MainAppBase(ConsoleApp, ABC):
         if flow_id:
             popup_class = self.class_by_name(class_name)
             if popup_class:
-                popup_kwargs = event_kwargs.get('popup_kwargs', dict())
+                popup_kwargs = event_kwargs.get('popup_kwargs', {})
                 self.open_popup(popup_class, **popup_kwargs)
                 return True
         return False
@@ -1314,7 +1316,7 @@ class MainAppBase(ConsoleApp, ABC):
         filter_func = (lambda _wg: isinstance(_wg, classes)) if classes else \
             (lambda _wg: callable(getattr(_wg, 'open', None)))
 
-        popups = list()
+        popups = []
         for wid in self.framework_win.children + self.framework_root.children:
             if filter_func(wid):
                 popups.append(wid)
@@ -1326,7 +1328,7 @@ class MainAppBase(ConsoleApp, ABC):
 
         :return:                dict with all app states available in the config files.
         """
-        app_states = dict()
+        app_states = {}
         for key in self.app_state_keys():
             app_states[key] = getattr(self, key)
 
